WindowState class

Constructors

WindowState({required int x, required int y, required int width, required int height, required bool isMaximized, required bool isMinimized})

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
isMaximized bool
getter/setter pair
isMinimized bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) WindowState