WindowUtilsApi class
Constructors
- WindowUtilsApi({BinaryMessenger? binaryMessenger})
-
Constructor for WindowUtilsApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeWindow(
) → Future< void> -
configureWindow(
) → Future< void> -
getScreenRadius(
) → Future< double> -
getWindowState(
) → Future< WindowState> -
isWindowMaximized(
) → Future< bool> -
maximizeWindow(
) → Future< void> -
minimizeWindow(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSystemGestureExclusionRects(
List< Rect?> arg_rects) → Future<void> -
setWindowPosition(
int arg_x, int arg_y) → Future< bool> -
setWindowSize(
int arg_width, int arg_height) → Future< bool> -
setWindowTitle(
String arg_title) → Future< void> -
startDragging(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
codec
→ const MessageCodec<
Object?>